@@ -11,7 +11,6 @@
 
 #pragma once
 
-#include <KTextEditor/MainWindow>
 #include <QJsonObject>
 #include <QWidget>
 
@@ -32,6 +31,15 @@ class QToolButton;
 class KActionCollection;
 class KConfigGroup;
 class KatePluginGDB;
+namespace DebugPluginSessionConfig
+{
+struct ConfigData;
+}
+
+namespace KTextEditor
+{
+class MainWindow;
+}
 
 struct GDBTargetConf {
     QString targetName;
@@ -44,7 +52,7 @@ struct GDBTargetConf {
 };
 
 struct DAPAdapterSettings {
-    int index;
+    int index{};
     QJsonObject settings;
     QStringList variables;
 };
@@ -61,16 +69,12 @@ class ConfigView : public QWidget
 {
     Q_OBJECT
 public:
-    enum TargetStringOrder { NameIndex = 0, ExecIndex, WorkDirIndex, ArgsIndex, GDBIndex, CustomStartIndex };
-
-    ConfigView(QWidget *parent, KTextEditor::MainWindow *mainWin, KatePluginGDB *plugin);
+    ConfigView(QWidget *parent, KTextEditor::MainWindow *mainWin, KatePluginGDB *plugin, KSelectAction *targetsAction);
     ~ConfigView() override;
 
 public:
-    void registerActions(KActionCollection *actionCollection);
-
-    void readConfig(const KConfigGroup &config);
-    void writeConfig(KConfigGroup &config);
+    void readConfig(const DebugPluginSessionConfig::ConfigData &config);
+    void writeConfig(DebugPluginSessionConfig::ConfigData &config);
 
     const GDBTargetConf currentGDBTarget() const;
     const DAPTargetConf currentDAPTarget(bool full = false) const;
@@ -93,6 +97,7 @@ private Q_SLOTS:
     void slotAdvancedClicked();
     void slotBrowseExec();
     void slotBrowseDir();
+    void readTargetsFromLaunchJson();
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
@@ -108,6 +113,8 @@ private:
     Field &getDapField(const QString &fieldName);
     void refreshUI();
     void readDAPSettings();
+    void initProjectPlugin();
+    void setTargetsAction(KSelectAction *action);
 
 private:
     KTextEditor::MainWindow *m_mainWindow;
