@@ -3,6 +3,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "OpenLinkPlugin.h"
+#include "matchers.h"
 
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -117,6 +118,7 @@ public:
         currentWord.clear();
     }
 
+    OpenLinkType linkType = HttpLink;
     QString currentWord;
     QPointer<QWidget> viewInternal;
 
@@ -194,28 +196,14 @@ void OpenLinkPluginView::clear(KTextEditor::Document *doc)
 void OpenLinkPluginView::gotoLink()
 {
     const QUrl u = QUrl::fromUserInput(m_ctrlHoverFeedback->currentWord);
-    if (u.isValid()) {
-        QDesktopServices::openUrl(u);
-    }
-}
-
-static const QRegularExpression &linkRE()
-{
-    static const QRegularExpression re(
-        QStringLiteral(R"re((https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)))re"));
-    return re;
-}
-
-static void adjustMDLink(const QString &line, int capturedStart, int &capturedEnd)
-{
-    if (capturedStart > 1) { // at least two chars before
-        int i = capturedStart - 1;
-        // for markdown [asd](google.com) style urls, make sure to strip last `)`
-        bool isMD = line.at(i - 1) == QLatin1Char(']') && line.at(i) == QLatin1Char('(');
-        if (isMD) {
-            int f = line.lastIndexOf(QLatin1Char(')'), capturedEnd >= line.size() ? line.size() - 1 : capturedEnd);
-            capturedEnd = f != -1 ? f : capturedEnd;
+    if (m_ctrlHoverFeedback->linkType == HttpLink) {
+        if (u.isValid()) {
+            QDesktopServices::openUrl(u);
         }
+    } else if (m_ctrlHoverFeedback->linkType == FileLink) {
+        m_mainWindow->openUrl(u);
+    } else {
+        Q_ASSERT(false);
     }
 }
 
@@ -231,16 +219,17 @@ void OpenLinkPluginView::highlightIfLink(KTextEditor::Cursor c, QWidget *viewInt
         return;
     }
 
-    auto match = linkRE().match(line);
-    const int capturedStart = match.capturedStart();
-    int capturedEnd = match.capturedEnd();
-
-    if (match.hasMatch() && capturedStart <= c.column() && c.column() <= capturedEnd) {
-        adjustMDLink(line, capturedStart, capturedEnd);
-        m_ctrlHoverFeedback->currentWord = line.mid(capturedStart, capturedEnd - capturedStart);
-        m_ctrlHoverFeedback->viewInternal = viewInternal;
-        KTextEditor::Range range(c.line(), capturedStart, c.line(), capturedEnd);
-        m_ctrlHoverFeedback->highlight(m_activeView, range);
+    std::vector<OpenLinkRange> matchedRanges;
+    matchLine(line, &matchedRanges);
+    for (auto [start, end, type] : matchedRanges) {
+        if (start <= c.column() && c.column() <= end) {
+            m_ctrlHoverFeedback->currentWord = line.mid(start, end - start);
+            m_ctrlHoverFeedback->viewInternal = viewInternal;
+            m_ctrlHoverFeedback->linkType = type;
+            KTextEditor::Range range(c.line(), start, c.line(), end);
+            m_ctrlHoverFeedback->highlight(m_activeView, range);
+            break;
+        }
     }
 }
 
@@ -267,6 +256,18 @@ void OpenLinkPluginView::onViewScrolled()
     highlightLinks(KTextEditor::Range::invalid());
 }
 
+static KTextEditor::MovingRange *highlightRange(KTextEditor::Document *doc, KTextEditor::Range range)
+{
+    KTextEditor::MovingRange *r = doc->newMovingRange(range);
+    static const KTextEditor::Attribute::Ptr attr([] {
+        auto attr = new KTextEditor::Attribute;
+        attr->setUnderlineStyle(QTextCharFormat::SingleUnderline);
+        return attr;
+    }());
+    r->setAttribute(attr);
+    return r;
+}
+
 void OpenLinkPluginView::highlightLinks(KTextEditor::Range range)
 {
     if (!m_activeView) {
@@ -289,25 +290,18 @@ void OpenLinkPluginView::highlightLinks(KTextEditor::Range range)
         ranges.clear();
     }
     // Loop over visible lines and highlight links
-    for (int i = startLine; i <= endLine; ++i) {
+    int linesChecked = 0;
+    std::vector<OpenLinkRange> matchedRanges;
+    for (int i = startLine; i <= endLine; ++i, ++linesChecked) {
+        // avoid checking too many lines
+        if (linesChecked > 400) {
+            break;
+        }
         const QString line = doc->line(i);
-        QRegularExpressionMatchIterator it = linkRE().globalMatch(line);
-        while (it.hasNext()) {
-            auto match = it.next();
-            if (match.hasMatch()) {
-                int capturedEnd = match.capturedEnd();
-                adjustMDLink(line, match.capturedStart(), capturedEnd);
-                KTextEditor::Range range(i, match.capturedStart(), i, capturedEnd);
-                KTextEditor::MovingRange *r = doc->newMovingRange(range);
-                static const KTextEditor::Attribute::Ptr attr([] {
-                    auto attr = new KTextEditor::Attribute;
-                    attr->setUnderlineStyle(QTextCharFormat::SingleUnderline);
-                    return attr;
-                }());
-                r->setAttribute(attr);
-                ranges.emplace_back(r);
-                // qDebug() << match.captured() << match.capturedStart() << match.capturedEnd();
-            }
+        matchLine(line, &matchedRanges);
+        for (auto [startCol, endCol, _] : matchedRanges) {
+            KTextEditor::Range range(i, startCol, i, endCol);
+            ranges.emplace_back(highlightRange(doc, range));
         }
     }
 }
@@ -354,4 +348,3 @@ bool OpenLinkPluginView::eventFilter(QObject *obj, QEvent *event)
 }
 
 #include "OpenLinkPlugin.moc"
-#include "moc_OpenLinkPlugin.cpp"
