@@ -25,7 +25,6 @@ class MainWindow;
 
 class BranchesDialog : public HUDDialog
 {
-    Q_OBJECT
 public:
     BranchesDialog(QWidget *window, QString projectPath);
     void openDialog(GitUtils::RefType r);
@@ -35,10 +34,7 @@ public:
         return m_branch;
     }
 
-Q_SIGNALS:
-    void branchSelected(const QString &branch);
-
-private Q_SLOTS:
+private:
     void slotReturnPressed(const QModelIndex &index) override;
 
 protected:
