@@ -144,6 +144,13 @@ public:
         connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, updateColors);
     }
 
+    double distance(QPoint p1, QPoint p2)
+    {
+        auto dx = (p1.x() - p2.x());
+        auto dy = (p1.y() - p2.y());
+        return sqrt((dx * dx) + (dy * dy));
+    }
+
     bool eventFilter(QObject *o, QEvent *e) override
     {
         switch (e->type()) {
@@ -165,6 +172,13 @@ public:
                 return false;
             }
 
+            // initialize distance between current mouse pos and top left corner of the tooltip
+            if (prevDistance == 0.0) {
+                auto pt = static_cast<QSinglePointEvent *>(e)->globalPosition().toPoint();
+                prevDistance = distance(pt, mapToGlobal(rect().topLeft()));
+                return false;
+            }
+
             auto pt = static_cast<QSinglePointEvent *>(e)->globalPosition().toPoint();
             auto cursor = m_view->coordinatesToCursor(m_view->mapFromGlobal(pt));
             // we are hovering over the word for which this tooltip exists, dont hide
@@ -172,9 +186,15 @@ public:
                 return false;
             }
 
+            auto newDistance = distance(pt, mapToGlobal(rect().topLeft()));
             auto pos = mapFromGlobal(static_cast<QSinglePointEvent *>(e)->globalPosition()).toPoint();
             if (!m_manual && !hasFocus() && !rect().contains(pos)) {
-                hideTooltip();
+                if (newDistance > prevDistance) {
+                    prevDistance = newDistance;
+                    hideTooltipWithDelay();
+                } else {
+                    prevDistance = newDistance;
+                }
             }
         } break;
         case QEvent::MouseButtonPress:
@@ -357,6 +377,7 @@ private:
     TooltipHighlighter *m_hl;
     bool m_manual;
     HintState m_hintState;
+    double prevDistance = 0.0;
     const KTextEditor::Range m_hoveredWordRange;
 };
 
